///////////////////////////////////////////////////////////////////////////////
//
//  File Name 
//      EVENTLOG.CPP
//
//  Description
//      This file implements the logging functions of the service
//
//  Author
//      Irving De la Cruz (irvingd@microsoft.com)
//
//  Revision: 1.1
//
// Written for Microsoft Corporation.
// Copyright (c) 1996-1997 Microsoft Corporation. All rights reserved.
//
#include "DIRMON.H"

HANDLE g_hEventLog = NULL;

///////////////////////////////////////////////////////////////////////////////
//    InitEventLog()
//
//    Parameters
//      None
//
//    Purpose
//      Initialize the handle to the event log source so that we may
//      report events
//
//    Return Value
//      A Win32 error code
//
DWORD WINAPI InitEventLog()
{
    if (g_hEventLog)
    {
        return NO_ERROR;
    }
    g_hEventLog = RegisterEventSource (NULL, DIRMON_EVENTLOG_SOURCE);
    if (!g_hEventLog)
    {
        DWORD dwError = GetLastError();
        return dwError;
    }
    return NO_ERROR;
}

///////////////////////////////////////////////////////////////////////////////
//    UnInitEventLog()
//
//    Parameters
//      None
//
//    Purpose
//      Releases a previously aquired handle to the event log source used
//      in this session of the service
//
//    Return Value
//      None
//
void WINAPI UnInitEventLog()
{
    if (g_hEventLog)
    {
        DeregisterEventSource (g_hEventLog);
    }
}

///////////////////////////////////////////////////////////////////////////////
//    LogEvent()
//
//    Parameters
//      [IN]    fError      TRUE if the log entry is an error. FALSE otherwise
//      [IN]    dwEventID   ID of the string in the message table resource
//      [IN]    dwData      Error for the entry or other data that will be
//                          inserted in the event log entry. This could be 0.
//      [IN]    rgszMsgs    If this is not NULL, it is an array of strings
//                          that will be insert in the formatted string
//      [IN]    wCount      Number of strings in rgszMsgs
//      [IN]    hResult     If non-zero, this is an HRESULT code for an
//                          error log entry
//
//    Purpose
//      Log an entry to the Event Log service with the arguments (if any)
//      specified by the caller.
//
//    Return Value
//      None
//
void WINAPI LogEvent (BOOL      fError,
                      DWORD     dwEventID,
                      DWORD     dwData,
                      LPSTR     rgszMsgs[],
                      WORD      wCount,
                      HRESULT   hResult)
{
    char szBuffer[64] = { 0 };
    LPSTR rgszError[] =
    {
        szBuffer
    };
    WORD wEventType = (fError ? EVENTLOG_ERROR_TYPE : EVENTLOG_INFORMATION_TYPE);
    if (fError && NULL == rgszMsgs)
    {
        if (hResult)
        {
            wsprintfA (szBuffer, "%#08x", hResult);
        }
        else
        {
            wsprintf (szBuffer, "%d", dwData);
        }
        rgszMsgs = rgszError;
        wCount = 1;
    }
    ReportEvent (g_hEventLog,
		         wEventType, 
		         DIRMON_CATEGORY,
		         dwEventID,
		         NULL,
		         wCount,
		         0,
		         (LPCSTR *)rgszMsgs,
		         NULL);
}

// End of file for EVENTLOG.CPP
